        function getT(rr,cc){
       if(rr==4 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260611 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==4 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260611 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>40</strong> miembros: 15 <strong>control</strong><br>0,6,7,11,13,18,20,26,27,30,33,40,42,49,50';}
       if(rr==4 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260611 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>1</strong> miembros: 10 <br>1,2,3,8,10,14,21,25,39,47';}
       if(rr==4 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260611 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>3</strong> representante: <strong>37</strong> miembros: 10 <br>9,16,31,32,36,37,38,43,46,48';}
       if(rr==4 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260611 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>4</strong> representante: <strong>15</strong> miembros: 9 <br>4,5,15,19,24,28,34,35,41';}
       if(rr==4 && cc==5){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260611 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>5</strong> representante: <strong>12</strong> miembros: 7 <br>12,17,22,23,29,44,45';}
       if(rr==23 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260611 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==23 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260611 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>40</strong> miembros: 15 <strong>control</strong><br>0,6,7,11,13,18,20,26,27,30,33,40,42,49,50';}
       if(rr==23 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260611 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>1</strong> miembros: 10 <br>1,2,3,8,10,14,21,25,39,47';}
       if(rr==23 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260611 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>3</strong> representante: <strong>37</strong> miembros: 10 <br>9,16,31,32,36,37,38,43,46,48';}
       if(rr==23 && cc==4){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260611 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>4</strong> representante: <strong>15</strong> miembros: 9 <br>4,5,15,19,24,28,34,35,41';}
       if(rr==23 && cc==5){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260611 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>5</strong> representante: <strong>12</strong> miembros: 7 <br>12,17,22,23,29,44,45';}
       if(rr==25 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260611 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==25 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260611 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>40</strong> miembros: 15 <strong>control</strong><br>0,6,7,11,13,18,20,26,27,30,33,40,42,49,50';}
       if(rr==25 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260611 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>1</strong> miembros: 10 <br>1,2,3,8,10,14,21,25,39,47';}
       if(rr==25 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260611 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>3</strong> representante: <strong>37</strong> miembros: 10 <br>9,16,31,32,36,37,38,43,46,48';}
       if(rr==25 && cc==4){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260611 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>4</strong> representante: <strong>15</strong> miembros: 9 <br>4,5,15,19,24,28,34,35,41';}
       if(rr==25 && cc==5){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260611 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>5</strong> representante: <strong>12</strong> miembros: 7 <br>12,17,22,23,29,44,45';}
       if(rr==26 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260611 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==26 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260611 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>40</strong> miembros: 15 <strong>control</strong><br>0,6,7,11,13,18,20,26,27,30,33,40,42,49,50';}
       if(rr==26 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260611 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>1</strong> miembros: 10 <br>1,2,3,8,10,14,21,25,39,47';}
       if(rr==26 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260611 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>3</strong> representante: <strong>37</strong> miembros: 10 <br>9,16,31,32,36,37,38,43,46,48';}
       if(rr==26 && cc==4){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260611 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>4</strong> representante: <strong>15</strong> miembros: 9 <br>4,5,15,19,24,28,34,35,41';}
       if(rr==26 && cc==5){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260611 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>5</strong> representante: <strong>12</strong> miembros: 7 <br>12,17,22,23,29,44,45';}
       if(rr==27 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260611 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==27 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260611 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>40</strong> miembros: 15 <strong>control</strong><br>0,6,7,11,13,18,20,26,27,30,33,40,42,49,50';}
       if(rr==27 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260611 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>1</strong> miembros: 10 <br>1,2,3,8,10,14,21,25,39,47';}
       if(rr==27 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260611 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>3</strong> representante: <strong>37</strong> miembros: 10 <br>9,16,31,32,36,37,38,43,46,48';}
       if(rr==27 && cc==4){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260611 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>4</strong> representante: <strong>15</strong> miembros: 9 <br>4,5,15,19,24,28,34,35,41';}
       if(rr==27 && cc==5){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260611 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>5</strong> representante: <strong>12</strong> miembros: 7 <br>12,17,22,23,29,44,45';}
       if(rr==28 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260611 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==28 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260611 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>40</strong> miembros: 15 <strong>control</strong><br>0,6,7,11,13,18,20,26,27,30,33,40,42,49,50';}
       if(rr==28 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260611 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>1</strong> miembros: 10 <br>1,2,3,8,10,14,21,25,39,47';}
       if(rr==28 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260611 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>3</strong> representante: <strong>37</strong> miembros: 10 <br>9,16,31,32,36,37,38,43,46,48';}
       if(rr==28 && cc==4){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260611 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>4</strong> representante: <strong>15</strong> miembros: 9 <br>4,5,15,19,24,28,34,35,41';}
       if(rr==28 && cc==5){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260611 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>5</strong> representante: <strong>12</strong> miembros: 7 <br>12,17,22,23,29,44,45';}
}
